@@ -79,6 +79,8 @@ func TestBreakdownFormatJsonWithTags(t *testing.T) {
 		&GoldenFileOptions{
 			CaptureLogs: true,
 			IsJSON:      true,
+		}, func(ctx *config.RunContext) {
+			ctx.Config.TagPoliciesEnabled = true
 		},
 	)
 }
@@ -994,3 +996,15 @@ func TestBreakdownWithFreeResourcesChecksum(t *testing.T) {
 			ctx.Config.TagPoliciesEnabled = true
 		})
 }
+
+func TestBreakdownWithDataBlocksInSubmod(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", dir,
+		}, nil)
+}
