@@ -109,7 +109,7 @@ func commentGitLabCmd(ctx *config.RunContext) *cobra.Command {
 					return err
 				}
 
-				pricingClient := apiclient.NewPricingAPIClient(ctx)
+				pricingClient := apiclient.GetPricingAPIClient(ctx)
 				err = pricingClient.AddEvent("infracost-comment", ctx.EventEnv())
 				if err != nil {
 					logging.Logger.WithError(err).Error("could not report infracost-comment event")
