@@ -2,7 +2,6 @@ package apiclient
 
 import (
 	"bytes"
-	"crypto/tls"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -18,10 +17,10 @@ import (
 )
 
 type APIClient struct {
-	endpoint  string
-	apiKey    string
-	tlsConfig *tls.Config
-	uuid      uuid.UUID
+	httpClient *http.Client
+	endpoint   string
+	apiKey     string
+	uuid       uuid.UUID
 }
 
 type GraphQLQuery struct {
@@ -69,12 +68,11 @@ func (c *APIClient) doRequest(method string, path string, d interface{}) ([]byte
 
 	c.AddAuthHeaders(req)
 
-	// Use the DefaultTransport since this handles the HTTP/HTTPS proxy and other defaults
-	// and add the TLS config that was passed into the client
-	transport := http.DefaultTransport.(*http.Transport)
-	transport.TLSClientConfig = c.tlsConfig
+	client := c.httpClient
+	if client == nil {
+		client = http.DefaultClient
+	}
 
-	client := &http.Client{Transport: transport}
 	resp, err := client.Do(req)
 	if err != nil {
 		return []byte{}, errors.Wrap(err, "Error sending API request")
