@@ -108,10 +108,11 @@ func NewEvaluator(
 	blockBuilder BlockBuilder,
 	spinFunc ui.SpinnerFunc,
 	logger *logrus.Entry,
+	parentContext *Context,
 ) *Evaluator {
 	ctx := NewContext(&hcl.EvalContext{
 		Functions: ExpFunctions(module.RootPath, logger),
-	}, nil, logger)
+	}, parentContext, logger)
 
 	if visitedModules == nil {
 		visitedModules = make(map[string]map[string]cty.Value)
@@ -313,6 +314,17 @@ func (e *Evaluator) evaluateModules() {
 
 		e.visitedModules[fullName] = vars
 
+		// create a parent context which will be passed to any submodules. This will only
+		// contain the context values for the provider block as this is the only context
+		// values that should be "inherited".
+		parentContext := NewContext(&hcl.EvalContext{
+			Functions: ExpFunctions(e.module.RootPath, e.logger),
+		}, nil, e.logger)
+		providers := e.getValuesByBlockType("provider")
+		for key, provider := range providers.AsValueMap() {
+			parentContext.Set(provider, key)
+		}
+
 		moduleEvaluator := NewEvaluator(
 			Module{
 				Name:       fullName,
@@ -332,6 +344,7 @@ func (e *Evaluator) evaluateModules() {
 			e.blockBuilder,
 			nil,
 			e.logger,
+			parentContext,
 		)
 
 		moduleCall.Module, _ = moduleEvaluator.Run()
@@ -473,17 +486,15 @@ func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
 
 		value := forEachAttr.Value()
 		if !value.IsNull() && value.IsKnown() && forEachAttr.IsIterable() {
-			typeLabel := block.TypeLabel()
-			nameLabel := block.NameLabel()
-			if block.Type() == "module" {
-				typeLabel = block.Type()
-				nameLabel = block.TypeLabel()
+			labels := block.Labels()
+			if block.Type() != "resource" {
+				labels = append([]string{block.Type()}, labels...)
 			}
 
 			// set the context to an empty object so that we don't have any of the prior unexpanded attributes
 			// like id/arn e.t.c polluting the expansion. Otherwise we can end up with lots of expanded resources
 			// with attribute names e.g. aws_instance.test[id], aws_instance.test[arn].
-			e.ctx.Set(cty.ObjectVal(make(map[string]cty.Value)), typeLabel, nameLabel)
+			e.ctx.Set(cty.ObjectVal(make(map[string]cty.Value)), labels...)
 
 			value.ForEachElement(func(key cty.Value, val cty.Value) bool {
 				clone := e.blockBuilder.CloneBlock(block, key)
@@ -503,7 +514,7 @@ func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
 				ctx.Set(val, block.TypeLabel(), "value")
 
 				cloneValues := clone.Values()
-				e.ctx.Set(cloneValues, typeLabel, nameLabel, keyStr)
+				e.ctx.Set(cloneValues, append(labels, keyStr)...)
 
 				if v, ok := e.moduleCalls[clone.FullName()]; ok {
 					v.Definition = clone
@@ -624,11 +635,19 @@ func (e *Evaluator) convertType(b *Block, val cty.Value, attrType *Attribute) (c
 		return val, nil
 	}
 
-	ty, diag := typeexpr.TypeConstraint(attrType.HCLAttr.Expr)
+	ty, def, diag := typeexpr.TypeConstraintWithDefaults(attrType.HCLAttr.Expr)
 	if diag.HasErrors() {
 		e.logger.WithError(diag).Debugf("error trying to convert variable %s to type %s", b.Label(), attrType.AsString())
 		return val, nil
 	}
+
+	// Check if default values exist for the variable type definition. If they do, we
+	// merge these defaults with any existing values. This ensures that variables
+	// with optional types that have default values e.g., optional(string, "foo")
+	// are fully resolved.
+	if def != nil {
+		val = def.Apply(val)
+	}
 	return convert.Convert(val, ty)
 }
 
