@@ -1,9 +1,10 @@
 package azure
 
 import (
+	"github.com/tidwall/gjson"
+
 	"github.com/infracost/infracost/internal/providers/terraform/provider_schemas"
 	"github.com/infracost/infracost/internal/schema"
-	"github.com/tidwall/gjson"
 )
 
 var DefaultProviderRegion = "eastus"
@@ -24,8 +25,8 @@ func GetResourceRegion(resourceType string, v gjson.Result) string {
 	return ""
 }
 
-func ParseTags(resourceType string, r gjson.Result) *map[string]string {
-	_, supportsTags := provider_schemas.AzureTagsSupport[resourceType]
+func ParseTags(r *schema.ResourceData) *map[string]string {
+	_, supportsTags := provider_schemas.AzureTagsSupport[r.Type]
 	rTags := r.Get("tags").Map()
 	if !supportsTags && len(rTags) == 0 {
 		return nil
