@@ -2,7 +2,6 @@ package terraform
 
 import (
 	"bytes"
-	"encoding/json"
 	"fmt"
 	"net/url"
 	"os"
@@ -86,7 +85,7 @@ func (p *DirProvider) DisplayType() string {
 func (p *DirProvider) checks() error {
 	binary := p.TerraformBinary
 
-	p.ctx.SetContextValue("terraformBinary", binary)
+	p.ctx.ContextValues.SetValue("terraformBinary", binary)
 
 	_, err := exec.LookPath(binary)
 	if err != nil {
@@ -105,8 +104,8 @@ func (p *DirProvider) checks() error {
 	fullVersion := strings.SplitN(string(out), "\n", 2)[0]
 	version := shortTerraformVersion(fullVersion)
 
-	p.ctx.SetContextValue("terraformFullVersion", fullVersion)
-	p.ctx.SetContextValue("terraformVersion", version)
+	p.ctx.ContextValues.SetValue("terraformFullVersion", fullVersion)
+	p.ctx.ContextValues.SetValue("terraformVersion", version)
 
 	return checkTerraformVersion(version, fullVersion)
 }
@@ -183,11 +182,13 @@ func (p *DirProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, e
 		project := schema.NewProject(name, metadata)
 
 		parser := NewParser(p.ctx, p.includePastResources)
-		pastpartialResources, partialResources, err := parser.parseJSON(j, usage)
+		pastpartialResources, partialResources, providerMetadatas, err := parser.parseJSON(j, usage)
 		if err != nil {
 			return projects, errors.Wrap(err, "Error parsing Terraform JSON")
 		}
 
+		project.AddProviderMetadata(providerMetadatas)
+
 		project.HasDiff = !p.UseState
 		if project.HasDiff {
 			project.PartialPastResources = pastpartialResources
@@ -335,7 +336,7 @@ func (p *DirProvider) runPlan(opts *CmdOptions, spinner *ui.Spinner, initOnFail
 		// If the plan returns this error then Terraform is configured with remote execution mode
 		if isTerraformRemoteExecutionErr(extractedErr) {
 			log.Info("Continuing with Terraform Remote Execution Mode")
-			p.ctx.SetContextValue("terraformRemoteExecutionModeEnabled", true)
+			p.ctx.ContextValues.SetValue("terraformRemoteExecutionModeEnabled", true)
 			planJSON, err = p.runRemotePlan(opts, args)
 		} else if initOnFail && isTerraformInitErr(extractedErr) {
 			spinner.Stop()
